# rajdeepghosh

A simple Python package to open Rajdeep Ghosh's portfolio website.

## Installation

```bash
pip install rajdeepghosh
```

## Usage

```python
from rajdeepghosh import website

website()  # Opens Rajdeep's portfolio website in your default browser
```

## License
MIT